#!/bin/sh
#
# SiteManager Embedded for Linux
# Installer script
#
# (c) Copyright 2014-2016 Secomea A/S, Denmark.  All rights reserved
#

if [ "`id -u`" -ne 0 ] ; then
    echo "Please install SiteManager as root (use su or sudo)."
    exit 1
fi
    

[ -f sitemanager ] || exit 1

MORE=cat
if more /dev/null </dev/null; then MORE=more ; fi >/dev/null 2>/dev/null

(
echo "+----------------------------------------------------------------------"
echo "|"
sed -e 's/^/| /' -e '/INSTALLATION/,$d' README
echo "|"
echo "| *** BY CONTINUING WITH THE INSTALLATION, YOU ACCEPT THESE TERMS. ***"
echo "|"
echo "+----------------------------------------------------------------------"
) | $MORE


echo
echo -n "Accept terms and continue with installation (yes,no) [no] "
read OK

case "${OK}" in
    [Yy]*) ;;
    *) echo "Installation cancelled." ;	exit 0 ;;
esac


chmod +x sitemanager-x64 sitemanager

BITS=
if ./sitemanager -v; then
    BITS=32
    TARGET=x86
    SOURCE=sitemanager
elif ./sitemanager-x64 -v; then
    BITS=64
    TARGET=x64
    SOURCE=sitemanager-x64
fi >/dev/null 2>/dev/null

if [ -z "$BITS"  ] ; then
    echo "SiteManager executable not compatible with this platform."
    exit 9
fi

SM=./$SOURCE

cat<<EOF


==============================================================

EOF
echo -n "Installing "
$SM -v

cat<<EOF

==============================================================

EOF

RCSCRIPT=/etc/init.d/sitemanager

if [ -f $RCSCRIPT ] ; then
    SMDIR=
    grep '^SMDIR=' $RCSCRIPT > _INSTDIR
    . ./_INSTDIR
    rm -f _INSTDIR
    INSTDIR="$SMDIR"
    [ -d "$SMDIR" -a -f "$SMDIR/sitemanager" ] && "$RCSCRIPT" stop quiet
fi

if [ -d "$CFGDIR" ] ; then
    $SM -KILL
fi

if [ -z "$INSTDIR" ] ; then
    INSTDIR=/usr/local/sitemanager
fi

echo -n "Installation directory: [$INSTDIR] "
read SMDIR
if [ -z "$SMDIR" ] ; then
    SMDIR="$INSTDIR"
fi

[ -d "$SMDIR" ] || mkdir -p "$SMDIR" || exit 1

CFGDIR=/etc/sitemanager
CFG=$CFGDIR/sme.txt
SM="$SMDIR/sitemanager"

cp $SOURCE "$SM"
chown root.root "$SM"
chmod 6755 "$SM"

echo "Installed $SM ($TARGET) executable."

if [ -d /etc/init.d ] ; then
    sed -e "s:__DIR__:$SMDIR:" sitemanager.rc > $RCSCRIPT
    if [ -f $RCSCRIPT ] ; then
	chmod 755 $RCSCRIPT
	if which chkconfig > /dev/null 2>&1 ; then
	    chkconfig --add sitemanager
	else
	    for L in 0 1 6 ; do
		ln -f -s ../init.d/sitemanager /etc/rc$L.d/K01sitemanager
	    done
	    for L in 2 3 4 5 ; do
		ln -f -s ../init.d/sitemanager /etc/rc$L.d/S99sitemanager
	    done
	fi
    fi
    echo Installed $RCSCRIPT script.
elif grep sitemanager /etc/rc.local ; then
    echo > /dev/null
else
    echo "# Start SiteManager Embedded" >> /etc/rc.local
    echo "$SM start" >> /etc/rc.local
fi


if [ ! -f $CFG ] ; then
    echo
    echo "Create SiteManager configuration (hit Enter to configure later):"
    echo 

    echo -n "GateManager Server (Hostname or IP): "
    read GMHOST

    if [ -n "$GMHOST" ] ; then
	echo -n "GateManager Token: "
	read GMTOKEN
	echo -n "SiteManager Name: "
	read SMNAME

	mkdir -p $CFGDIR
	echo "Server=$GMHOST" > $CFG
	[ -n "$GMTOKEN" ] && echo "Domain=$GMTOKEN" >> $CFG
	[ -n "$SMNAME" ] && echo "Name=$SMNAME" >> $CFG
    fi
fi

if [ -f $CFG ] ; then
    echo
    echo -n "Start SiteManager Service now (yn)? [yes] "
    read START

    case "${START}Y" in
	[Yy]*)
	    if [ -f $RCSCRIPT ] ; then
		$RCSCRIPT start
	    else
		"$SM" start
	    fi
	    ;;
    esac
fi

cat<<EOF

==============================================================

Installation complete.

You can configure SiteManager via the following URL:
   http://127.0.0.1:11444

==============================================================

EOF
